---
name: Feature request
about: Ask for an improvement
title: "[Request]"
labels: ''
assignees: ''

---

**Describe the request:**

A clear and concise description of what you would like added to Crema.. 
